Extract the most important sentences which were identified by textrank_sentences
# S3 method for textrank_sentences
summary(object, n = 3, keep.sentence.order = FALSE, ...)an object of class textrank_sentences
integer indicating to extract only the top n sentences
logical indicating to keep the sentence order as provided
in the original data argument of the textrank_sentences function
or to order it by the pagerank score. Defaults to FALSE indicating to order by pagerank score.
not used
a character vector with the top n most important sentences
which were identified by textrank_sentences